PBA
========

PBA is a probability bound analysis library for Python. That allows for the creation of pboxes and intervals within python

Probability distributions can be specified using
``pba.distname(**args)`` for all distribution that scipy.stats supports.
Using interval arguments return p-boxes

Intervals can be created using 

Features
--------

- Interval Arithmetic
- P-box Arithmetic

Installation
-------------

Install pba by running:

    pip install pba

Contribute & Support
--------------------

If you are having issues or would like to help with development or have intersting use cases, please let us know.
You can email nickgray@liv.ac.uk

License
--------

The project is licensed under the MIT License.
